from django.contrib.auth.models import AbstractUser
from django.db import models
from django.utils.text import slugify
from django.utils.translation import ugettext_lazy as _

from taggit.managers import TaggableManager
from wagtail.admin.edit_handlers import FieldPanel, MultiFieldPanel,\
    StreamFieldPanel
from wagtail.core.fields import RichTextField, StreamField
from wagtail.images.edit_handlers import ImageChooserPanel

class AbstractModel(models.Model):
    creation_date = models.DateTimeField(
        auto_now_add=True,
        verbose_name=_('Creation date'))
    edition_date = models.DateTimeField(
        auto_now=True,
        verbose_name=_('Edition date'))
    hidden = models.BooleanField(
        default=False,
        verbose_name=_('Hidden'))

    class Meta:
        abstract = True

class BaseModel(AbstractModel):
    title = models.CharField(
        max_length=255,
        verbose_name=_('Title'))

    class Meta:
        abstract = True

    def __str__(self):
        return self.title

class SEOModel(BaseModel):
    seo_title = models.CharField(
        blank=True,
        max_length=255,
        verbose_name=_('SEO Title'),
        help_text=_("Optional. 'Search Engine Friendly' title. This will appear at the top of the browser window."))
    slug = models.SlugField(
        allow_unicode=True,
        max_length=255,
        verbose_name=_('Slug'),
        help_text=_('The name of the page as it will appear in URLs e.g http://domain.com/blog/[my-slug]/'))
    search_description = models.TextField(
        verbose_name=_('Search Description'),
        blank=True)
    keywords = TaggableManager(
        verbose_name=_('Keywords'))
    include_in_sitemap = models.BooleanField(
        default=True,
        help_text=_('Should this page appear in the sitemap'))
    show_in_menus = models.BooleanField(
        default=False,
        verbose_name=_('Show in menus'),
        help_text=_('Whether a link to this page will appear in automatically generated menus'))
    # url_path = models.TextField(verbose_name=_('URL path'), blank=True, editable=False)
    url_reverse_name = None

    seo_panels = [
        MultiFieldPanel(
            children=[
                FieldPanel('seo_title'),
                FieldPanel('slug'),
                FieldPanel('search_description'),
                FieldPanel('keywords'),
                FieldPanel('include_in_sitemap'),
                FieldPanel('show_in_menus'),
            ]
        ),
    ]

    class Meta:
        abstract = True

    def get_url(self, kwargs={}):
        url = '/'
        if self.url_reverse_name and self.slug:
            props = {
                'pk': self.id,
                'slug': self.slug,
            }
            url = reverse(self.url_reverse_name, kwargs=dict(kwargs, **props))
        return url

    def save(self, *args, **kwargs):
        value = self.title
        self.slug = slugify(value, allow_unicode=True)
        super().save(*args, **kwargs)


class SelectableModel(SEOModel):
    class Meta:
        abstract = True

    @classmethod
    def get_list(cls, showHidden=False, limit=5, desc=False):
        query = cls.objects
        if not showHidden:
            query = query.filter(hidden=False)
        if not desc:
            query = query.order_by('-id')
        return query[:limit]


class AbstractCustomUser(AbstractUser):
    REQUIRED_FIELDS = ['username']

    class Meta:
        verbose_name = _('User')
        verbose_name_plural = _('Users')
        abstract = True

    def __str__(self):
        return self.username

    def email_user(self, subject, message, from_email=None, **kwargs):
        if self.email:    
            """Send an email to this user."""
            send_mail(subject, message, from_email, [self.email], **kwargs)



# Generated by Django 2.2.6 on 2019-10-17 16:46

from django.db import migrations, models
import django.db.models.deletion
import wagtailschemaorg.registry


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0041_group_collection_permissions_verbose_name_plural'),
        ('configuration', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='OrganizationInfoSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(help_text="Your organization's public name", max_length=100, verbose_name='Name')),
                ('phone_number', models.CharField(blank=True, help_text='Public phone number', max_length=20, verbose_name='Phone number')),
                ('email', models.EmailField(blank=True, help_text='Public contact email', max_length=254, verbose_name='Email')),
                ('twitter_handle', models.CharField(blank=True, help_text='Without the @', max_length=15, verbose_name='Twitter handle')),
                ('facebook_url', models.URLField(blank=True, help_text="Page's url in facebook", verbose_name='Facebook')),
                ('twitter_url', models.URLField(blank=True, help_text="Page's url in twitter", verbose_name='Twitter')),
                ('instagram_url', models.URLField(blank=True, help_text="Page's url in instagram", verbose_name='Instagram')),
                ('linkedin_url', models.URLField(blank=True, help_text="Page's url in linkedin", verbose_name='LinkedIn')),
                ('youtube_url', models.URLField(blank=True, help_text="Page's url in youtube", verbose_name='Youtube')),
                ('vimeo_url', models.URLField(blank=True, help_text="Page's url in vimeo", verbose_name='Vimeo')),
                ('googleplus_url', models.URLField(blank=True, help_text="Page's url in google plus", verbose_name='Google Plus')),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site')),
            ],
            options={
                'verbose_name': 'Social',
                'verbose_name_plural': 'Social',
            },
            bases=(wagtailschemaorg.registry.SiteThingLD, models.Model),
        ),
        migrations.DeleteModel(
            name='SocialSettings',
        ),
    ]



from django.db import models
from django.utils.translation import ugettext_lazy as _

from taggit.managers import TaggableManager
from wagtail.admin.edit_handlers import FieldPanel, MultiFieldPanel,\
    StreamFieldPanel
from wagtail.api import APIField
from wagtail.core.fields import RichTextField, StreamField
from wagtail.core.models import Page as CorePage
from wagtail.images.edit_handlers import ImageChooserPanel


class Page(CorePage):
    include_in_sitemap = models.BooleanField(
        default=True,
        help_text=_('Should this page appear in the sitemap'))
    promote_image = models.ForeignKey(
        'wagtailimages.Image',
        null=True,
        blank=True,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name=_('Share Image'),
        help_text=_('1200x630 preferably'))
    keywords = TaggableManager(
        verbose_name=_('Keywords'))
    promote_panels = [
        MultiFieldPanel(
            [
                FieldPanel('seo_title', 'Title'),
                FieldPanel('search_description', 'Description'),
                FieldPanel('keywords', 'Keywords'),
                ImageChooserPanel('promote_image'),
            ],
            _('SEO configuration')),
        MultiFieldPanel(
            [
                FieldPanel('slug'),
                FieldPanel('include_in_sitemap'),
                FieldPanel('show_in_menus'),
            ],
            _('Site Configuration')),
    ]

    class Meta:
        abstract = True

    def get_sitemap_urls(self, request):
        if not self.include_in_sitemap:
            return []
        else:
            return super(Page, self).get_sitemap_urls(request)


from django.core.validators import MinLengthValidator, MinValueValidator, \
    MaxValueValidator
from django.db import models
from django.utils.translation import ugettext, ugettext_lazy

from wagtail.admin.edit_handlers import TabbedInterface, ObjectList, \
  FieldPanel, PageChooserPanel, MultiFieldPanel
from wagtail.contrib.settings.models import BaseSetting, register_setting
from wagtail.images.edit_handlers import ImageChooserPanel
from wagtailschemaorg.models import BaseLDSetting
from wagtailschemaorg.registry import register_site_thing
from wagtailschemaorg.utils import extend


@register_setting(icon='form')
@register_site_thing
class OrganizationInfoSettings(BaseLDSetting):
    name = models.CharField(
        max_length=100,
        help_text=ugettext_lazy('Your organization\'s public name'),
        verbose_name=ugettext_lazy('Name'))
    phone_number = models.CharField(
        blank=True,
        max_length=20,
        help_text=ugettext_lazy('Public phone number'),
        verbose_name=ugettext_lazy('Phone number'))
    email = models.EmailField(
        blank=True,
        help_text=ugettext_lazy('Public contact email'),
        verbose_name=ugettext_lazy('Email'))
    twitter_handle = models.CharField(
        max_length=15,
        blank=True,
        help_text=ugettext_lazy('Without the @'),
        verbose_name=ugettext_lazy('Twitter handle'))

    facebook_url = models.URLField(
        blank=True,
        help_text=ugettext_lazy('Page\'s url in facebook'),
        verbose_name=ugettext_lazy('Facebook'))
    twitter_url = models.URLField(
        blank=True,
        help_text=ugettext_lazy('Page\'s url in twitter'),
        verbose_name=ugettext_lazy('Twitter'))
    instagram_url = models.URLField(
        blank=True,
        help_text=ugettext_lazy('Page\'s url in instagram'),
        verbose_name=ugettext_lazy('Instagram'))
    linkedin_url = models.URLField(
        blank=True,
        help_text=ugettext_lazy('Page\'s url in linkedin'),
        verbose_name=ugettext_lazy('LinkedIn'))
    youtube_url = models.URLField(
        blank=True,
        help_text=ugettext_lazy('Page\'s url in youtube'),
        verbose_name=ugettext_lazy('Youtube'))
    vimeo_url = models.URLField(
        blank=True,
        help_text=ugettext_lazy('Page\'s url in vimeo'),
        verbose_name=ugettext_lazy('Vimeo'))
    googleplus_url = models.URLField(
        blank=True,
        help_text=ugettext_lazy('Page\'s url in google plus'),
        verbose_name=ugettext_lazy('Google Plus'))
    
    organization_tab_panels = [
        MultiFieldPanel([
            FieldPanel('name'),
            FieldPanel('phone_number'),
            FieldPanel('email'),
            FieldPanel('twitter_handle'),
        ], heading=ugettext_lazy('General Information')),
    ]

    social_tab_panels = [
        MultiFieldPanel([
            FieldPanel('instagram_url'),
            FieldPanel('linkedin_url'),
            FieldPanel('twitter_url'),
            FieldPanel('facebook_url'),
            FieldPanel('youtube_url'),
            FieldPanel('vimeo_url'),
            FieldPanel('googleplus_url'),
        ], heading=ugettext_lazy('URLs')),
    ]

    edit_handler = TabbedInterface([
        ObjectList(organization_tab_panels, heading=ugettext_lazy('General Information')),
        ObjectList(social_tab_panels, heading=ugettext_lazy('Social Links')),
    ])

    class Meta:
        verbose_name = ugettext_lazy('Organization')
        verbose_name_plural = ugettext_lazy('Organization')

    def ld_generate_organization(self):
        customData = {
            '@type': 'Organization',
            'sameAs': [
                self.twitter_url,
                self.facebook_url,
            ],
        }
        sameAs = []
        if self.name: customData['name'] = self.name
        if self.email: customData['email'] = self.email
        if self.phone_number: customData['telephone'] = self.phone_number
        if self.twitter_url: sameAs.append(self.twitter_url)
        if self.facebook_url: sameAs.append(self.facebook_url)
        if self.instagram_url: sameAs.append(self.instagram_url)
        if self.linkedin_url: sameAs.append(self.linkedin_url)
        if self.youtube_url: sameAs.append(self.youtube_url)
        if self.vimeo_url: sameAs.append(self.vimeo_url)
        if self.googleplus_url: sameAs.append(self.googleplus_url)
        customData['sameAs'] = sameAs
        return customData

    # def ld_generate_website(self):
    #     customData = {
    #         '@type': 'WebSite',
    #     }
    #     return customData

    def ld_entity(self):
        organization = self.ld_generate_organization()
        # website = self.ld_generate_website()
        return extend(super().ld_entity(), organization)


@register_setting(icon='password')
class OtherSettings(BaseSetting):
    sentry_active = models.BooleanField(
        default=False,
        verbose_name=ugettext_lazy('Activate'))
    sentry_dsn = models.URLField(
        blank=True,
        help_text=ugettext_lazy('Get it from sentry.io'),
        verbose_name=ugettext_lazy('DSN for frontend error reporting'))
    google_recaptcha_public = models.CharField(
        blank=False,
        max_length=255,
        verbose_name=ugettext_lazy('Recaptcha Public Key'))
    google_recaptcha_secret = models.CharField(
        blank=False,
        max_length=255,
        verbose_name=ugettext_lazy('Recaptcha Secret Key'))
    ssl_on = models.BooleanField(
        default=False,
        verbose_name=ugettext_lazy('Is SSL active?'))

    CRITERIA_TIME = 'Express'
    CRITERIA_PRICE = 'Normal'
    CRITERIA_CHOICES = (
        (CRITERIA_TIME, ugettext_lazy('Express')),
        (CRITERIA_PRICE, ugettext_lazy('Normal')),
    )
    sending_criteria = models.CharField(
        blank=False,
        max_length=14,
        default=CRITERIA_PRICE,
        choices=CRITERIA_CHOICES,
        verbose_name=ugettext_lazy('Preference'))

    apis_tab_panels = [
        MultiFieldPanel([
            FieldPanel('sending_criteria'),
        ], heading=ugettext_lazy('Sending Criteria')),
        MultiFieldPanel([
            FieldPanel('ssl_on'),
        ], heading=ugettext_lazy('Site')),
        MultiFieldPanel([
            FieldPanel('google_recaptcha_public'),
            FieldPanel('google_recaptcha_secret'),
        ], heading=ugettext_lazy('Recaptcha')),
        MultiFieldPanel([
            FieldPanel('sentry_active'),
            FieldPanel('sentry_dsn'),
        ], heading='Sentry'),
    ]

    edit_handler = TabbedInterface([
        ObjectList(apis_tab_panels, heading=ugettext_lazy('Security')),
    ])

    class Meta:
        verbose_name = ugettext_lazy('Security')
        verbose_name_plural = ugettext_lazy('Security')


@register_setting(icon='warning')
class AnalyticsSettings(BaseSetting):
    facebook_pixel = models.CharField(
        blank=True,
        max_length=70,
        verbose_name=ugettext_lazy('Pixel ID'))
    facebook_account = models.CharField(
        blank=True,
        max_length=70,
        verbose_name=ugettext_lazy('Account ID'))
    facebook_app = models.CharField(
        blank=True,
        max_length=70,
        verbose_name=ugettext_lazy('App ID'))
    google_analytics_enabled = models.BooleanField(
        default=False,
        blank=True,
        verbose_name=ugettext_lazy('Analytics enabled'))
    google_analytics_id = models.CharField(
        blank=True,
        max_length=255,
        verbose_name=ugettext_lazy('Analytics ID'))
    google_adwords_enabled = models.BooleanField(
        default=False,
        blank=True,
        verbose_name=ugettext_lazy('Adwords enabled'))
    google_adwords_id = models.CharField(
        blank=True,
        max_length=255,
        verbose_name=ugettext_lazy('Adwords ID'))
    google_tagmanager_enabled = models.BooleanField(
        default=False,
        blank=True,
        verbose_name=ugettext_lazy('Tagmanager enabled'))
    google_tagmanager_id = models.CharField(
        blank=True,
        max_length=255,
        verbose_name=ugettext_lazy('TagManager ID'))
    google_site_verification = models.CharField(
        blank=True,
        max_length=255,
        verbose_name=ugettext_lazy('Site Verification Key'))
    
    default_title = models.CharField(
        blank=False,
        max_length=300,
        verbose_name=ugettext_lazy('Title'))
    title_suffix = models.CharField(
        blank=False,
        default='Wuafbox',
        max_length=40,
        help_text=ugettext_lazy('For SEO the pages will appear in this manner: Title | Suffix'),
        verbose_name=ugettext_lazy('Title Suffix'))
    default_description = models.CharField(
        blank=False,
        max_length=255,
        verbose_name=ugettext_lazy('Description'))
    default_promote_image = models.ForeignKey(
        'wagtailimages.Image',
        null=True,
        blank=False,
        on_delete=models.SET_NULL,
        related_name='+',
        verbose_name=ugettext_lazy('Share Image'),
        help_text=ugettext_lazy(
            'Image used by default for the SEO metas. 1200x630 preferably'
        ))
    default_language = models.CharField(
        default='es',
        choices=(
            ('es', 'Spanish'),
            ('en', 'English'),
        ),
        max_length=6,
        verbose_name=ugettext_lazy('Language'))

    other_tab_panels = [
        MultiFieldPanel([
            FieldPanel('title_suffix'),
            FieldPanel('default_title'),
            FieldPanel('default_description'),
            ImageChooserPanel('default_promote_image'),
            FieldPanel('default_language'),
        ], heading=ugettext_lazy('SEO Defaults')),
    ]
    keys_panels = [
        MultiFieldPanel([
            FieldPanel('google_analytics_id'),
            FieldPanel('google_analytics_enabled'),
            FieldPanel('google_tagmanager_id'),
            FieldPanel('google_tagmanager_enabled'),
            FieldPanel('google_adwords_id'),
            FieldPanel('google_adwords_enabled'),
            FieldPanel('google_site_verification'),
        ], heading=ugettext_lazy('Google')),
        MultiFieldPanel([
            FieldPanel('facebook_pixel'),
            FieldPanel('facebook_account'),
            FieldPanel('facebook_app'),
        ], heading=ugettext_lazy('Facebook'))
    ]

    edit_handler = TabbedInterface([
        ObjectList(other_tab_panels, heading=ugettext_lazy('Defaults')),
        ObjectList(keys_panels, heading=ugettext_lazy('APIs')),
    ])

    class Meta:
        verbose_name = ugettext_lazy('SEO')
        verbose_name_plural = ugettext_lazy('SEO')





from django_frontera.contrib.utils.version import get_semver_version, get_version

# dev
# alpha
# beta
# rc
# final
VERSION = (0, 0, 4, 'dev', 13)

__version__ = get_version(VERSION)

# Required for npm package for frontend
__semver__ = get_semver_version(VERSION)


# Generated by Django 2.2.6 on 2019-10-15 18:57

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailimages', '0001_squashed_0021'),
        ('wagtailcore', '0041_group_collection_permissions_verbose_name_plural'),
    ]

    operations = [
        migrations.CreateModel(
            name='SocialSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('facebook_url', models.URLField(blank=True, help_text="Page's url in facebook", verbose_name='Facebook')),
                ('twitter_handle', models.CharField(blank=True, help_text='Without the @', max_length=255, verbose_name='Twitter handle')),
                ('twitter_url', models.URLField(blank=True, help_text="Page's url in twitter", verbose_name='Twitter')),
                ('instagram_url', models.URLField(blank=True, help_text="Page's url in instagram", verbose_name='Instagram')),
                ('linkedin_url', models.URLField(blank=True, help_text="Page's url in linkedin", verbose_name='LinkedIn')),
                ('youtube_url', models.URLField(blank=True, help_text="Page's url in youtube", verbose_name='Youtube')),
                ('vimeo_url', models.URLField(blank=True, help_text="Page's url in vimeo", verbose_name='Vimeo')),
                ('googleplus_url', models.URLField(blank=True, help_text="Page's url in google plus", verbose_name='Google Plus')),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site')),
            ],
            options={
                'verbose_name': 'Social',
                'verbose_name_plural': 'Social',
            },
        ),
        migrations.CreateModel(
            name='OtherSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('sentry_active', models.BooleanField(default=False, verbose_name='Activate')),
                ('sentry_dsn', models.URLField(blank=True, help_text='Get it from sentry.io', verbose_name='DSN for frontend error reporting')),
                ('google_recaptcha_public', models.CharField(max_length=255, verbose_name='Recaptcha Public Key')),
                ('google_recaptcha_secret', models.CharField(max_length=255, verbose_name='Recaptcha Secret Key')),
                ('ssl_on', models.BooleanField(default=False, verbose_name='Is SSL active?')),
                ('sending_criteria', models.CharField(choices=[('Express', 'Express'), ('Normal', 'Normal')], default='Normal', max_length=14, verbose_name='Preference')),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site')),
            ],
            options={
                'verbose_name': 'Security',
                'verbose_name_plural': 'Security',
            },
        ),
        migrations.CreateModel(
            name='AnalyticsSettings',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('facebook_pixel', models.CharField(blank=True, max_length=70, verbose_name='Pixel ID')),
                ('facebook_account', models.CharField(blank=True, max_length=70, verbose_name='Account ID')),
                ('facebook_app', models.CharField(blank=True, max_length=70, verbose_name='App ID')),
                ('google_analytics_enabled', models.BooleanField(blank=True, default=False, verbose_name='Analytics enabled')),
                ('google_analytics_id', models.CharField(blank=True, max_length=255, verbose_name='Analytics ID')),
                ('google_adwords_enabled', models.BooleanField(blank=True, default=False, verbose_name='Adwords enabled')),
                ('google_adwords_id', models.CharField(blank=True, max_length=255, verbose_name='Adwords ID')),
                ('google_tagmanager_enabled', models.BooleanField(blank=True, default=False, verbose_name='Tagmanager enabled')),
                ('google_tagmanager_id', models.CharField(blank=True, max_length=255, verbose_name='TagManager ID')),
                ('google_site_verification', models.CharField(blank=True, max_length=255, verbose_name='Site Verification Key')),
                ('default_title', models.CharField(max_length=300, verbose_name='Title')),
                ('title_suffix', models.CharField(default='Wuafbox', help_text='For SEO the pages will appear in this manner: Title | Suffix', max_length=40, verbose_name='Title Suffix')),
                ('default_description', models.CharField(max_length=255, verbose_name='Description')),
                ('default_language', models.CharField(choices=[('es', 'Spanish'), ('en', 'English')], default='es', max_length=6, verbose_name='Language')),
                ('default_promote_image', models.ForeignKey(help_text='Image used by default for the SEO metas. 1200x630 preferably', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image', verbose_name='Share Image')),
                ('site', models.OneToOneField(editable=False, on_delete=django.db.models.deletion.CASCADE, to='wagtailcore.Site')),
            ],
            options={
                'verbose_name': 'SEO',
                'verbose_name_plural': 'SEO',
            },
        ),
    ]



import time
from functools import wraps

PROF_DATA = {}


def log_time(fn):
    @wraps(fn)
    def with_profiling(*args, **kwargs):
        start_time = time.time()

        ret = fn(*args, **kwargs)

        elapsed_time = time.time() - start_time

        if fn.__name__ not in PROF_DATA:
            PROF_DATA[fn.__name__] = [0, []]
        PROF_DATA[fn.__name__][0] += 1
        PROF_DATA[fn.__name__][1].append(elapsed_time)

        return ret

    return with_profiling


def print_prof_data():
    for fname, data in PROF_DATA.items():
        max_time = max(data[1])
        avg_time = sum(data[1]) / len(data[1])
        print("Function %s called %d times. " % (fname, data[0]))
        print('Execution time max: %.3f, average: %.3f' % (max_time, avg_time))


def clear_prof_data():
    global PROF_DATA
    PROF_DATA = {}



# Obtained and modified from:
# http://goo.gl/XDH8QX

from __future__ import unicode_literals

from django import forms
from django.conf import settings
from django.contrib.auth import get_user_model
from django.contrib.auth.forms import PasswordResetForm as PRF
from django.contrib.auth.tokens import default_token_generator
from django.contrib.sites.shortcuts import get_current_site
from django.template import loader
from django.urls import reverse
from django.utils.encoding import force_bytes
from celery.utils.log import get_task_logger
from django.utils.http import urlsafe_base64_encode
from django.utils.translation import ugettext

from Wuafbox.tasks import sendMail

logger = get_task_logger('MainAPP.tasks')


class PasswordResetForm(PRF):
    def __init__(self, *args, **kwargs):
        super(PasswordResetForm, self).__init__(*args, **kwargs)
        self.fields['email'].widget.attrs['placeholder'] = ugettext(
            "alguien123@gmail.com")
        self.fields['email'].label = ugettext(
            "Correo Electrónico de la cuenta")

    def send_mail(self, email_template_id,
                  context, from_email, to_email,
                  html_email_template_name=None):
        """
        Sends a django.core.mail.EmailMultiAlternatives to `to_email`.
        """
        substitutions = {
            'to': to_email,
            'substitutions': {
                'subject': 'Recuperar mi contraseña de Wuafbox',
                'cta_text': 'Recuperar contraseña',
                'body': '''
                        <p>Para confirmar tu correo electrónico y recuperar tu contraseña da clic en el siguiente link:</p>
                    ''',
            },
            'html_content': '<strong>Recuperar contraseña</strong>',
            'template_id': email_template_id,
        }
        substitutions['substitutions'].update(context)
        sendMail(substitutions)


    def save(self, email_template_id, domain_override=None,
             use_https=False, token_generator=default_token_generator,
             from_email=None, request=None, html_email_template_name=None,
             extra_email_context=None):
        """
        Generates a one-use only link for resetting password and sends to the
        user.
        """
        email = self.cleaned_data["email"]
        for user in self.get_users(email):
            if not domain_override:
                current_site = get_current_site(request)
                site_name = current_site.name
                domain = current_site.domain
            else:
                site_name = domain = domain_override

            # {'-name-': self.validated_data['name'],
            #  '-company-': self.validated_data['company'],
            #  '-email-': self.validated_data['email'],
            #  '-accounts-': self.validated_data['accounts'],
            #  '-message-': self.validated_data['message']},
            protocol = 'https' if use_https else 'http'
            context = {
                'first_name': user.first_name,
                'cta_link': protocol + '://' + domain + reverse(
                    'password_reset_confirm', kwargs={
                        'uidb64': urlsafe_base64_encode(force_bytes(user.pk)).decode("utf-8"),
                        'token': token_generator.make_token(user),
                    })}
            if extra_email_context is not None:
                context.update(extra_email_context)
            self.send_mail(
                email_template_id=email_template_id,
                context=context,
                from_email=from_email,
                to_email=(user.email, user.first_name),
                html_email_template_name=html_email_template_name
            )




from django.contrib import messages
from django.contrib.staticfiles.storage import staticfiles_storage
from django.urls import reverse
from django.utils.translation import gettext, ngettext

from jinja2 import Environment

# DEPRECATED .... NOT REQUIRED. USED DJANGO_JINJA INSTEAD OF PLAIN JINJA2


# def environment(**options):
#     env = Environment(**options)
#     env.globals.update({
#        'static': staticfiles_storage.url,
#        'url': reverse,
#     })
#     return env


def environment(**options):
    options['extensions'] += ['jinja2.ext.i18n']
    env = Environment(**options)

    env.install_gettext_callables(
        gettext=gettext, ngettext=ngettext, newstyle=True)

    env.globals.update({
        'get_messages': messages.get_messages,
    })
    return env



from django.contrib import messages
from django.utils.translation import ugettext_lazy


GRAY = 'gray'
GREEN = 'green'
BLUE = 'blue'
YELLOW = 'yellow'
RED = 'red'

NO_TITLE = ''
SUCCESS = ugettext_lazy('Éxito')
ERROR = ugettext_lazy('Error')
WARNING = ugettext_lazy('Lo sentimos')

errors_list = {
    'title': {
        '400': ugettext_lazy('Bad Request'),
        '401': ugettext_lazy('Unauthorized'),
        '403': ugettext_lazy('Prohibido'),
        '404': ugettext_lazy('Not Found'),
        '405': ugettext_lazy('Method not allowed'),
        '406': ugettext_lazy('Not Acceptable'),
        '409': ugettext_lazy('Conflicto'),
        '415': ugettext_lazy('Unsupported Media Type'),
        '500': ugettext_lazy('Error en el servidor'),
        '503': ugettext_lazy('Service Unavailable'),
        'sorry': ugettext_lazy('Lo sentimos'),
    },
    'body': {
        'no_action': ugettext_lazy(
            'We are sorry. You are trying to execute an unknown'
            ' or prohibited action.'),
        'incorrect_method': ugettext_lazy(
            'We are sorry. You are trying to execute an'
            ' action with an incorrect header or'
            ' method.'),
        'missing_step': ugettext_lazy(
            'We are sorry. You must complete the previous'
            ' steps to execute this action.'),
        'bad_login': ugettext_lazy(
            'La combinación de usuario/contraseña es inválida. Por favor'
            ' intentalo de nuevo.'),
        'no_perm': ugettext_lazy(
            'Usted no tiene suficientes permisos para ejecutar esta'
            ' acción. Si esto es un error, por favor, contacte a su'
            ' administrador.'),
        'ticket': ugettext_lazy(
            'Un error interno ha ocurrido en el sistema. El administrador ha'
            ' sido notificado.'),
        'encryption': ugettext_lazy(
            'La combinación de cer, key y contraseña es incorrecta.'
            ' Los cambios en estos 3 campos se han descartado.'),
        'verification_pending': ugettext_lazy(
            'Aún no ha verificado su correo electrónico.'),
        'verification_error': ugettext_lazy(
            'El correo no existe en el sistema o ya fue'
            ' verificado anteriormente.'),
        'email_inc_exists': ugettext_lazy(
            'El correo electrónico está en un formato'
            ' invalido o ya existe en el sistema'),
        'team_join_exists': ugettext_lazy(
            'Este usuario ya se encuentra relacionado a un negocio,'
            ' no puede crear uno nuevo con la cuenta actual.'),
        'team_plan_exists': ugettext_lazy(
            'Su negocio ya se encuentra relacionado a un plan,'
            ' no puede crear una nueva subscripción sin antes cancelar la'
            ' existente.'),
        'join_exists': ugettext_lazy(
            'Este usuario ya se encuentra relacionado a un negocio, '
            'no puede unirse a otro con la cuenta actual.'),
        'no_join_exists': ugettext_lazy(
            'Este usuario no se encuentra relacionado a ningún negocio.'),
        'no_user_exists': ugettext_lazy(
            'El usuario no existe en el sistema.'),
        'not_in_team': ugettext_lazy(
            'Usted no pertenece a este negocio.'),
        'no_team': ugettext_lazy(
            'El negocio no existe en el sistema.'),
        'team_exists': ugettext_lazy(
            'El negocio ya existe en el sistema.'),
        'already_claimed': ugettext_lazy(
            'Esta invitación ya fue procesada anteriormente.'),
        'already_in_team': ugettext_lazy(
            'El usuario ya se encuentra en este negocio.'),
        'publication_not_exists': ugettext_lazy(
            'El anuncio no existe en el sistema.'),
        'invalid_data': ugettext_lazy(
            'La información es incorrecta.'),
        'profile_not_exists': ugettext_lazy(
            'El mostrador virtual no existe en el sistema.'),
    }
}


def generate_msg(request, state=GRAY, title='Debug', body='Empty'):
    mtype = None
    if state == GRAY:
        mtype = messages.DEBUG
    elif state == GREEN:
        mtype = messages.SUCCESS
    elif state == BLUE:
        mtype = messages.INFO
    elif state == YELLOW:
        mtype = messages.WARNING
    elif state == RED:
        mtype = messages.ERROR

    messages.add_message(
        request,
        mtype,
        extra_tags=title,
        message=body,
        fail_silently=True
    )


def _parseToJSON(message):
    return {
        'level': message.level_tag,
        'tags': message.extra_tags,
        'body': message.message,
    }


def getMessagesJSON(request):
    storage = messages.get_messages(request)
    array = list()
    for message in storage:
        array.append(_parseToJSON(message))
    return array



import jinja2.ext

from wagtailschemaorg.templatetags.wagtailschemaorg_tags import ld_print_entity, \
  ld_for_object, ld_for_site


class SchemaORGExtension(jinja2.ext.Extension):
    def __init__(self, environment):
        super(SchemaORGExtension, self).__init__(environment)
        environment.globals["ld_print_entity"] = jinja2.contextfunction(ld_print_entity)
        environment.globals["ld_for_object"] = jinja2.contextfunction(ld_for_object)
        environment.globals["ld_for_site"] = jinja2.contextfunction(ld_for_site)



import logging
from graphql import GraphQLError

class GraphQLLogFilter(logging.Filter):
    def filter(self, record):
        if 'graphql.error.located_error.GraphQLLocatedError:' in record.msg:
            return False
        return True




#!/usr/bin/env python

import sys
from django_frontera import __version__

try:
    from setuptools import setup, find_packages
except ImportError:
    from distutils.core import setup

readme = 'Hi'
readme_type = 'text'
with open('README.rst') as f:
    readme = f.read()
    readme_type = 'text/markdown'

install_requires = [

]

testing_extras = [
  'jinjalint>=0.5',
]

documentation_extras = [
  
]

setup(
    name='django-frontera',
    version=__version__,
    description='Utils used by Frontera.',
    author='frontera-hq',
    author_email='daniel.ortiz@nuu.co',  # For support queries, please see http://docs.wagtail.io/en/stable/support.html
    url='https://nuu.co/',
    packages=find_packages(),
    include_package_data=True,
    license='MIT',
    long_description=readme,
    long_description_content_type=readme_type,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Framework :: Django',
        'Framework :: Django :: 2.1',
        'Framework :: Django :: 2.2',
        'Framework :: Wagtail',
        'Topic :: Utilities',
    ],
    install_requires=install_requires,
    extras_require={
        'testing': testing_extras,
        'docs': documentation_extras
    },
    zip_safe=False,
)


from django.urls import get_resolver

from django.core.management.base import BaseCommand


class Command(BaseCommand):
    def handle(self, *args, **options):
        for key in set(v[1] for k,v in get_resolver(None).reverse_dict.items()):
          print(key)



from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _

class ConfigurationConfig(AppConfig):
    name = 'django_frontera.configuration'
    label = 'configuration'
    verbose_name = _('Configuration')
